@@ -481,7 +481,11 @@ class EmailSend(object):
 
 @ezfuc.retry(2)
 def getIP():
-    res = requests.get("http://elanpy.com:39111/?key=123").json()
+    try:
+        res = requests.get("http://192.168.18.8:39111/?key=123",timeout=3).json()
+    except:
+        return None
+
     if res["code"] ==200:
         return res
     elif res["code"] ==300:
@@ -490,7 +494,13 @@ def getIP():
         getIP()
 
 
+
 def ezproxy(req):
     res = getIP()
-    req.meta["proxy"] = res["proxy"]
-    return req
\ No newline at end of file
+    if not res:
+        return req
+    try:
+        req.meta["proxy"] = res["proxy"]
+        return req
+    except:
+        return req
\ No newline at end of file
